@@ -3,15 +3,14 @@
 ldap.controls.sss - classes for Server Side Sorting
 (see RFC 2891)
 
-See http://www.python-ldap.org/ for project details.
+See https://www.python-ldap.org/ for project details.
 
-$Id: sss.py,v 1.1 2015/06/22 16:47:08 stroeder Exp $
+$Id: sss.py,v 1.4 2017/08/15 16:21:58 stroeder Exp $
 """
 
 __all__ = [
     'SSSRequestControl',
     'SSSResponseControl',
-    'SSSVLVPagedLDAPObject'
 ]
 
 
@@ -49,7 +48,7 @@ class SortKeyListType(univ.SequenceOf):
 class SSSRequestControl(RequestControl):
     '''Order result server side
 
-        >>> s = SSSRequestControl('-cn')
+        >>> s = SSSRequestControl(ordering_rules=['-cn'])
     '''
     controlType = '1.2.840.113556.1.4.473'
 
