@@ -1,9 +1,9 @@
 """
 ldap.resiter - processing LDAP results with iterators
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-\$Id: resiter.py,v 1.7 2015/09/18 20:20:32 stroeder Exp $
+\$Id: resiter.py,v 1.8 2017/08/15 16:21:58 stroeder Exp $
 
 Python compability note:
 Requires Python 2.3+
