@@ -1,9 +1,9 @@
 """
 ldap.schema.subentry -  subschema subentry handling
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-\$Id: subentry.py,v 1.35 2015/06/06 09:21:38 stroeder Exp $
+\$Id: subentry.py,v 1.37 2017/08/15 16:21:58 stroeder Exp $
 """
 
 import ldap.cidict,ldap.schema
@@ -483,6 +483,7 @@ def urlfetch(uri,trace_level=0):
     subschemasubentry_dn,s_temp = ldif_parser.all_records[0]
   # Work-around for mixed-cased attribute names
   subschemasubentry_entry = ldap.cidict.cidict()
+  s_temp = s_temp or {}
   for at,av in s_temp.items():
     if at in SCHEMA_CLASS_MAPPING:
       try:
