@@ -2,12 +2,13 @@
 """
 Automatic tests for python-ldap
 
-See http://www.python-ldap.org/ for details.
+See https://www.python-ldap.org/ for details.
 
-$Id: __init__.py,v 1.5 2017/04/28 07:30:59 stroeder Exp $
+$Id: __init__.py,v 1.6 2017/08/15 16:17:29 stroeder Exp $
 """
 
 import t_cext
+import t_cidict
 import t_ldap_dn
 import t_ldap_filter
 import t_ldap_functions
